@@ -1,5 +1,4 @@
-"l1median" <-
-function (X, MaxStep = 200, ItTol = 10^-8)
+l1median = function (X, MaxStep = 200, ItTol = 10^-8)
 {
 	if (class (X) != "matrix")
 	{
@@ -9,19 +8,17 @@ function (X, MaxStep = 200, ItTol = 10^-8)
 			X = matrix(X, ncol = 1)
 	}
 
-	ret = .C ("l1median",
+	ret = .C ("l1median", PACKAGE="pcaPP",
 		as.double (X),
 		as.integer (nrow(X)),
 		as.integer (ncol(X)),
 		med = double (ncol(X)),
 		ret = integer(1),
 		as.integer (MaxStep),
-		as.double (ItTol),
-		PACKAGE = "pcaPP"
+		as.double (ItTol)
 		)
 
 	if (ret$ret != 0)
 		return (ret$med)
 	stop("iteration failed")
 }
-
